@@ -102,7 +102,6 @@ c ==============================================================================
       external dfsub
       external  gsub
       external  dgsub
-      character(len=150) msg
 
       integer nminit, iprint, idum
       logical  use_c, comp_c, giv_u
@@ -202,10 +201,8 @@ C     SCMODIFIED add an extra condition to avoid accessing xx(0)
 * nmax from size of u and xx
 
       if (iprint .ge. 0) then
-           write(msg,901) nmax
-           call rprint(msg)
+       CALL Rprinti1('Nmax from workspace =',nmax)
       end if
- 901   format(1h ,'nmax from workspace =',i8)
 
       if (nmax .le. 1) return
 
@@ -335,13 +332,6 @@ C     SCMODIFIED add an extra condition to avoid accessing xx(0)
       ilast = idhold +  ldhold
 
 
-      if (iprint .eq. 1) then
-        write(msg,903) ilast
-        call rprint(msg)
-      end if
- 903     format(1h ,'ilast',i10)
-
-
 *  Partition integer workspace.
 
       iiref = 1
@@ -360,8 +350,7 @@ C     SCMODIFIED add an extra condition to avoid accessing xx(0)
       lisign = ncomp*nmax
 
       if (iprint .eq. 1) then
-        write(msg,*) 'integer workspace', iisign+lisign
-        call rprint(msg)
+        CALL Rprinti1('Integer workspace', iisign+lisign)
       end if
 
       call bvpsol_l(ncomp, nmsh, nlbc, aleft, aright,
@@ -467,8 +456,6 @@ c ==============================================================================
       logical frscal
 c      save frscal
 
-      character(len=150) msg
-
 
       logical stab_kappa, stab_gamma, stab_cond, stiff_cond, ill_cond
       logical stab_kappa1, ill_cond_newt, stab_sigma, comparekappa
@@ -552,6 +539,8 @@ c Karline: use precis instead of d1mach
       ckappa     = flmax
       ckappaold  = flmax
       ckappa2    = flmax
+      sigma      = flmax
+      sigmaold   = flmax
       stiff_cond = .false.
       stab_cond  = .false.
       ill_cond   = .false.
@@ -586,8 +575,7 @@ c Karline: use precis instead of d1mach
            if (nmsh .ge. nmax ) then
             maxmsh = .true.
             if (iprint .eq. 1) THEN
-              write(msg,*)'Initial mesh greater then nmax'
-              CALL rprint(msg)
+             CALL Rprint('Initial mesh greater than nmax')
             ENDIF
 
             goto 900
@@ -599,19 +587,12 @@ c Karline: use precis instead of d1mach
             maxmsh = .true.
 
             if (iprint .eq. 1) THEN
-              write(msg,*)'Initial mesh greater then nmax'
-              CALL rprint(msg)
+             CALL Rprint('Initial mesh greater than nmax')
             ENDIF
 
             goto 900
          end if
 
-      if (iprint .ne. -1) then
-         write(msg,902)
-         call rprint(msg)
-         call sprt(nmsh, xx)
-      endif
-
        if (.not. giveu) call initu(ncomp, nmsh, xx, nudim, u,
      *    nygdim, nmguess,xguess, yguess)
       indnms = 0
@@ -632,8 +613,7 @@ c Karline: use precis instead of d1mach
       If(Maxmsh) goto 900
 
       if (iprint .eq. 1) THEN
-        write(msg,903) nmsh
-        CALL rprint(msg)
+       CALL Rprinti1('Start 4th order, nmsh', nmsh)
       ENDIF
 
 *  Set the def (deferred correction) array to zero.
@@ -705,17 +685,12 @@ c       BY BRUGNANO & TRIGIANTE, AND HIGHAM
 
 
            if (iprint .ge. 0) then
-            write(msg,1001) sigma
-            CALL rprint(msg)
-            write(msg,1002) gamma1
-            CALL rprint(msg)
-            write(msg,1003) ckappa1
-            CALL rprint(msg)
-            write(msg,1004) ckappa
-            CALL rprint(msg)
-            write(msg,1009) ckappa2
-            CALL rprint(msg)
-          end if
+            CALL Rprintd1('stiffness = ', sigma)
+            CALL Rprintd1('gamma1    = ', gamma1)
+            CALL Rprintd1('kappa1    = ', ckappa1)
+            CALL Rprintd1('kappa     = ', ckappa)           
+            CALL Rprintd1('kappa2    = ', ckappa2)
+           end if
 
           stab_sigma = abs(sigmaold-sigma)/(sigma).lt.5d-2
      *      .and. sigma .lt. flmax
@@ -742,18 +717,12 @@ c          stab_cond = stab_kappa1 .and. stab_gamma
           if (ill_cond .and. use_c) goto 2000
 
            if (iprint .eq. 1) then
-             write(msg,*) 'stab_sigma = ',stab_sigma
-             CALL rprint(msg)
-             write(msg,*) 'stab_kappa = ', stab_kappa
-             CALL rprint(msg)
-             write(msg,*) 'stab_kappa1 = ', stab_kappa1
-             CALL rprint(msg)
-             write(msg,*) 'stab_gamma = ', stab_gamma
-             CALL rprint(msg)
-             write(msg,*) 'stiff_cond = ', stiff_cond
-             CALL rprint(msg)
-             write(msg,*) 'ill_cond   = ', ill_cond
-             CALL rprint(msg)
+             CALL Rprintd1('stab_sigma = ',stab_sigma)
+             CALL Rprintd1('stab_kappa = ', stab_kappa)
+             CALL Rprintd1('stab_kappa1 = ', stab_kappa1)
+             CALL Rprintd1('stab_gamma = ', stab_gamma)
+             CALL Rprintd1('stiff_cond = ', stiff_cond)
+             CALL Rprinti1('ill_cond   = ', ill_cond)
            end if
         end if
 c endif if (comp_c)
@@ -786,17 +755,12 @@ c
 
 
            if (iprint .ge. 0) then
-            write(msg,1001) sigma
-            CALL rprint(msg)
-            write(msg,1002) gamma1
-            CALL rprint(msg)
-            write(msg,1003) ckappa1
-            CALL rprint(msg)
-            write(msg,1004) ckappa
-            CALL rprint(msg)
-            write(msg,1009) ckappa2
-            CALL rprint(msg)
-          end if
+            CALL Rprintd1('stiffness = ', sigma)
+            CALL Rprintd1('gamma1    = ', gamma1)
+            CALL Rprintd1('kappa1    = ', ckappa1)
+            CALL Rprintd1('kappa     = ', ckappa)           
+            CALL Rprintd1('kappa2    = ', ckappa2)
+           end if
 
           stab_sigma = abs(sigmaold-sigma)/(sigma).lt.5d-2
      *      .and. sigma .lt. flmax
@@ -822,18 +786,12 @@ c         stab_cond = stab_kappa1 .and. stab_gamma
 
 
            if (iprint .eq. 1) then
-             write(msg,*) 'stab_sigma = ',stab_sigma
-             CALL rprint(msg)
-             write(msg,*) 'stab_kappa = ', stab_kappa
-             CALL rprint(msg)
-             write(msg,*) 'stab_kappa1 = ', stab_kappa1
-             CALL rprint(msg)
-             write(msg,*) 'stab_gamma = ', stab_gamma
-             CALL rprint(msg)
-             write(msg,*) 'stiff_cond = ', stiff_cond
-             CALL rprint(msg)
-             write(msg,*) 'ill_cond   = ', ill_cond
-             CALL rprint(msg)
+             CALL Rprintd1('stab_sigma = ',stab_sigma)
+             CALL Rprintd1('stab_kappa = ', stab_kappa)
+             CALL Rprintd1('stab_kappa1 = ', stab_kappa1)
+             CALL Rprintd1('stab_gamma = ', stab_gamma)
+             CALL Rprintd1('stiff_cond = ', stiff_cond)
+             CALL Rprinti1('ill_cond   = ', ill_cond)
            end if
         end if
        end if
@@ -917,11 +875,8 @@ c   Now compute an explicit deferred correction for this.
 
            Ix=Ixx
            siz=abs(dgtm(Icmph))
-c           write(6,*) 'siz=',siz
            rat=siz/bigdef
-c           write(6,*) 'rat=',rat
-c           write(6,*) ' bigdef=',bigdef,' > ',dsqrt(tol(Icmph))
-c           write(6,*) ' dsq=', dsqrt(tol(Icmph))
+
           If(Rat.gt.50.0D+0.and.bigdef.gt.dsqrt(tol(Icmph)).and.
      +      siz.gt.1.0D+0) Then
 
@@ -930,10 +885,6 @@ c           write(6,*) ' dsq=', dsqrt(tol(Icmph))
              drat = bigdef/
      *               (max(one, abs(u(icmph,Ix)))*tol(intol))
 
-            if (iprint .ne. -1)then
-              write(msg,913) drat, u(icmph,Ix), tol(intol)
-              call rprint(msg)
-            end if
 c            numadd = drat**power
              numadd = 15
             call smpselcondmsh(ncomp, nmsh,
@@ -943,8 +894,7 @@ c            numadd = drat**power
          else
              drat = bigdef/
      *               (max(one, abs(u(icmph,Ix)))*tol(intol))
-C KARLINE REMOVED THIS
-c           if(iprint .ne. -1) write(6,913) drat, u(icmph,Ix), tol(intol)
+
 c            numadd = drat**power
              numadd = 15
                 call smpmsh (nmsh, nmax, xx, ix, numadd,
@@ -953,17 +903,13 @@ c            numadd = drat**power
        else
              drat = bigdef/
      *               (max(one, abs(u(icmph,Ix)))*tol(intol))
-            if (iprint .ne. -1) then
-               write(msg,913) drat, u(icmph,Ix), tol(intol)
-               call rprint(msg)
-            endif
             numadd = 15
 c            numadd = drat**power
             call smpmsh (nmsh, nmax, xx, Ix, numadd,
      *             nmold, xxold, maxmsh)
        end if
- 913     format(1h ,'drat,u,tol',3(1pe11.3))
-cf the solution is  intepolated, using the new  solution
+
+cf the solution is  interpolated, using the new  solution
          Call Matcop(Nudim, Ncomp, Ncomp, Nmold, U, Uold)
          Call Interp(Ncomp, Nmsh, Xx, Nudim,U,Ncomp,Nmold, Xxold, Uold)
          If(Maxmsh) goto 900
@@ -995,9 +941,6 @@ c       endif
       Call Matcop(Ncomp, Ncomp, Ncomp, Nmsh-1, Def, Def6)
 
 c      if (succes) then
-c          if (iprint .ne. -1 .and. comp_c ) then
-c            if (ckappa .ge. tolmin/epsmch) write(6,1005)
-c          end if
 c          iflbvp = 0
 c          return
       if (maxmsh) then
@@ -1011,7 +954,6 @@ c          return
 **** logic for 6th order ****
 
 c karline removed
-C      if (iprint .eq. 1) write(6,905)
 
 *  Save the 4th order solution on this mesh in uold.
 
@@ -1063,7 +1005,7 @@ c      call dcopy(nmold, xx, 1, xxold, 1)
 
       if (iflnwt .eq. 0) then
 
-C karline: what about "linear" -> rmoved
+C karline: what about 'linear' -> rmoved
 c         call conv6(ncomp, nmsh, ntol, ltol, tol,
 c     *             nudim, u, uold, etest6, err6,
 c     *             trst6, onto8, reaft6, linear, succes)
@@ -1093,8 +1035,8 @@ c     *             trst6, onto8, reaft6, linear, succes)
 
          if (iprint .ne. -1 .and. comp_c .and. use_c) then
            if (ill_cond) then
-              write(msg,1005)
-              call rprint(msg)
+             CALL Rprint('The problem is ill-conditioned, ')
+             CALL Rprint('The solution could be inaccurate')
            end if
          end if
          iflbvp = 0
@@ -1102,8 +1044,8 @@ c     *             trst6, onto8, reaft6, linear, succes)
             if (.not. stab_kappa .and. indnms .gt. 1) then
                  iflbvp = -1
                 if  (iprint .ne. -1) then
-                   write(msg,1010)
-                   call rprint(msg)
+        CALL Rprint('The conditioning parameters did not stabilise, ')
+        CALL Rprint('The solution could be inaccurate')
                 end if
             end if
             if (ill_cond) iflbvp = -2
@@ -1116,8 +1058,7 @@ c     *             trst6, onto8, reaft6, linear, succes)
 ***** logic for trying to calculate 8th order solution *****
 
       if (iprint .eq. 1)  then
-         write(msg,906)
-         call rprint(msg)
+             CALL Rprint('Start 8th order')
       end if
 
       call matcop(nudim, ncomp, ncomp, nmsh, u, uold)
@@ -1152,8 +1093,7 @@ c      call dcopy(nmold, xx, 1, xxold, 1)
       forcedouble = .false.
 
        if (iprint .eq. 1) then
-         write(msg,*) 'forcedouble', nodouble, itcond
-         call rprint(msg)
+         CALL Rprinti2('Forcedouble, itcond', nodouble, itcond)
        end if
 
        if (use_c .and.  itcond .eq. itcondmax) then
@@ -1268,8 +1208,8 @@ c      call dcopy(nmold, xx, 1, xxold, 1)
 
       if (iprint .ne. -1 .and. comp_c .and. use_c ) then
         if ( ill_cond ) then
-           write(msg,1005)
-           call rprint(msg)
+             CALL Rprint('The problem is ill-conditioned, ')
+             CALL Rprint('The solution could be inaccurate')
         end if
       end if
        iflbvp = 0
@@ -1277,8 +1217,8 @@ c      call dcopy(nmold, xx, 1, xxold, 1)
             if (.not. stab_kappa .and. indnms.gt.1) then
                 iflbvp = -1
                 if  (iprint .ne. -1) then
-                    write(msg,1010)
-                    call rprint(msg)
+       CALL Rprint('The conditioning parameters did not stabilise, ')
+       CALL Rprint('The solution could be inaccurate')
                 end if
              end if
              if (ill_cond) iflbvp=-2
@@ -1303,22 +1243,20 @@ c      call dcopy(nmold, xx, 1, xxold, 1)
 
       iflbvp = 1
       if (iprint .ge. 0   ) then
-         write(msg,*) 'Terminated, too many mesh points'
-         call rprint(msg)
+             CALL Rprint('Terminated, too many mesh points')
       end if
       if (nmsh .gt. nmold .and. use_c .and.
      *    abs(ckappaold-ckappa)/(ckappa) .lt. nmsh*1d-16 ) then
-
-             write(msg,*) 'Try with a less stringent tolerance '
-             call rprint(msg)
+      	 CALL Rprint('Try with a less stringent tolerance ')
       end if
         if (linear .and. ill_cond .and. use_c) then
-               write(msg,1006)
-               call rprint(msg)
+             CALL Rprint('The problem is ill-conditioned, ')
+             CALL Rprint('Try with a less stringent tolerance')
         end if
         if (.not.linear .and. ill_cond .and. use_c ) then
-             write(msg,1007)
-            call rprint(msg)
+             CALL Rprint('The problem is ill-conditioned, ')
+             CALL Rprint('Try with a less stringent tolerance ')
+             CALL Rprint(' or with a different initial guess' )
          end if
 
       return
@@ -1328,18 +1266,18 @@ c      call dcopy(nmold, xx, 1, xxold, 1)
 
       iflbvp = 2
       if (iprint .ne.-1) then
-        write(msg,1008) indnms
-        call rprint(msg)
+       CALL Rprinti1('Terminated too many meshes, nmsh ',indnms)
       end if
 
       if (iprint .ne. -1 .and. use_c ) then
         if (linear .and. ill_cond ) then
-           write(msg,1006)
-           call rprint(msg)
+             CALL Rprint('The problem is ill-conditioned, ')
+             CALL Rprint('Try with a less stringent tolerance')
         end if
         if (.not.linear .and. ill_cond )then
-            write(msg,1007)
-           call rprint(msg)
+             CALL Rprint('The problem is ill-conditioned, ')
+             CALL Rprint('Try with a less stringent tolerance ')
+             CALL Rprint(' or with a different initial guess' )
          end if
       end if
         return
@@ -1349,35 +1287,15 @@ c      call dcopy(nmold, xx, 1, xxold, 1)
          iflbvp = 3
          if (iprint .ne. -1) then
           if (linear) then
-            write(msg,1006)
-             call rprint(msg)
+             CALL Rprint('The problem is ill-conditioned, ')
+             CALL Rprint('Try with a less stringent tolerance')
           else
-            write(msg,1007)
-            call rprint(msg)
+             CALL Rprint('The problem is ill-conditioned, ')
+             CALL Rprint('Try with a less stringent tolerance ')
+             CALL Rprint(' or with a different initial guess' )
           end if
          end if
          return
- 901  format(1h ,'epsmch',1pe10.3)
- 902  format(1h ,'initial mesh')
- 903  format(1h ,'start 4th order, nmsh',i5)
- 904  format(1h ,'do not go on to 6th')
- 905  format(1h ,'start 6th order')
- 906  format(1h ,'start 8th order')
- 1001 format(1h ,'stiffness = ',1pe11.3)
- 1002 format(1h ,'gamma1    = ',1pe11.3)
- 1003 format(1h ,'kappa1    = ',1pe11.3)
- 1004 format(1h ,'kappa     = ',1pe11.3)
- 1009 format(1h ,'kappa2    = ',1pe11.3)
- 1005 format(1h ,'The problem is ill-conditioned, ',
-     *     'the solution could be inaccurate')
- 1006 format(1h ,'The problem is ill-conditioned, ',
-     *     'try with a less stringent tolerance')
- 1007 format(1h ,'The problem is ill-conditioned, ',
-     *     'try with a less stringent tolerance ',
-     *     ' or with a different initial guess' )
- 1008 format(1h ,'Terminated too many meshes, nmsh',i5)
- 1010 format(1h ,'The conditioning parameters did not stabilise, ',
-     *       'the solution could be inaccurate')
       end
 
 
@@ -1409,8 +1327,6 @@ C Karline: moved this statement upward
       integer nfunc, njac, nstep, nbound, njacbound
       common/diagnost/nfunc, njac, nstep, nbound, njacbound
 
-      character(len=150) msg
-
 
 c       St1 --> Tmp(ncomp,10)
 c       St2 --> Tmp(ncomp,11)
@@ -1511,10 +1427,8 @@ c
  60      Continue
 
          if (iprint.eq.1) then
-            write(msg,75)
-            call rprint(msg)
+             CALL Rprint('NO convergence of corrections')
          end if
- 75      format(1x,'no convergence of corrections')
 
          Return
 
@@ -1541,9 +1455,6 @@ c
 
       Return
 
- 900  Format('** Warning - Possibly Approaching Machine Precision ',
-     *         'Beyond Epsilon  = ',D10.3)
-
       End
 
 c ===================================================================================
@@ -1563,8 +1474,6 @@ C      dimension t1(2),t2(2),t3(2),t4(2)
       integer nfunc, njac, nstep, nbound, njacbound
       common/diagnost/nfunc, njac, nstep, nbound, njacbound
 
-      character(len=150) msg
-
       logical use_c,comp_c
       integer nminit, iprint, idum
 
@@ -1653,8 +1562,6 @@ c ==============================================================================
       integer nfunc, njac, nstep, nbound, njacbound
       common/diagnost/nfunc, njac, nstep, nbound, njacbound
 
-      character(len=150) msg
-
       JC=0
 c      St1 --> Tmp(ncomp,13)
 c      St2 --> Tmp(ncomp,14)
@@ -1769,10 +1676,8 @@ c      St4 --> Tmp(ncomp,16)
  80         Continue
 
          if (iprint.eq.1) then
-            write(msg,8930)
-            call rprint(msg)
+             CALL Rprint('NO convergence of 8th order defcors')
          end if
- 8930    format(1x,'no convergence of 8th order defcors')
 
       Return
  90   Continue
@@ -1788,9 +1693,6 @@ c      St4 --> Tmp(ncomp,16)
 
       Return
 
- 900  Format('** Warning - Possibly Approaching Machine Precision ',
-     *         'Beyond Epsilon  = ',D10.3)
-
       End
 
 c ===================================================================================
@@ -1892,32 +1794,3 @@ c ==============================================================================
 
 c ===================================================================================
 
-      subroutine sprt(n, array)
-* sprt prints an array. karline toggled off
-      implicit double precision (a-h,o-z)
-      dimension array(n)
-      character (len=150) msg
-
-c      write(msg,900) (array(i), i=1,n)
-c      call rprint(msg)
-c 900   format(1h ,(7(1pe11.3)))
-      return
-      end
-
-c ===================================================================================
-
-      subroutine mprt(nrowd, nrow, ncol, array)
-* mprt prints a matrix.
-      implicit double precision (a-h,o-z)
-      dimension array(nrowd, ncol)
-      character (len=150) msg
-c      do 400 i = 1, nrow
-c         write(msg,900) i,(array(i,j), j=1,ncol)
-c         call rprint(msg)
-c 400      continue
-c 900       format(1h ,i5,(6(1pe11.3)))
-      return
-      end
-
-
-
